==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_auv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuèlh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a ges d’article a aquela adreça ',
	'aucun_auteur' => 'I a ges d’autor a aquela adreça ',
	'aucun_site' => 'I a ges de sit a aquela adreça ',
	'aucune_breve' => 'I a ges de brèva a aquela adreça ',
	'aucune_rubrique' => 'I a ges de rubrica a aquela adreça ',
	'autres_breves' => 'Autras brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots claus',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bonjorn',

	// C
	'commenter_site' => 'Comentar aquel sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrèir apondon',
	'dernieres_breves' => 'Darrèiras brèvas',
	'derniers_articles' => 'Darrèirs articles',
	'derniers_commentaires' => 'Darrèirs comentaris',
	'derniers_messages_forum' => 'Darrèirs messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En responsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau mesme autor',
	'meme_rubrique' => 'Dins la mesma rubrica',
	'memes_auteurs' => 'Daus mesmes autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots claus',
	'mots_clefs_meme_groupe' => 'Mots claus dins lo mesme grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats sobre lo web',
	'nouveaux_articles' => 'Articles nuòus',
	'nouvelles_breves' => 'Brèvas nuòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podètz participar a la vida d’aquel sit e prepausar los articles vòstres en vos inscriure çai sos. Recebretz tot sitòst un e-mail que vos indicará vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podètz prepausar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respondre a aquel article',
	'repondre_breve' => 'Respondre a aquela brèva',
	'resultats_recherche' => 'Resultats de la cèrcha',
	'retour_debut_forums' => 'Retorn au començament daus forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat amb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguda',
	'sur_web' => 'Sobre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Aquela letra recensa los articles e brèvas publicats dempuèi', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Vejatz en linha',
	'voir_squelette' => 'telecharjar l’esqueleta d’aquela pagina'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_auv
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Acuèlh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a ges d’article a aquela adreça ',
	'aucun_auteur' => 'I a ges d’autor a aquela adreça ',
	'aucun_site' => 'I a ges de sit a aquela adreça ',
	'aucune_breve' => 'I a ges de brèva a aquela adreça ',
	'aucune_rubrique' => 'I a ges de rubrica a aquela adreça ',
	'autres_breves' => 'Autras brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots claus',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bonjorn',

	// C
	'commenter_site' => 'Comentar aquel sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrèir apondon',
	'dernieres_breves' => 'Darrèiras brèvas',
	'derniers_articles' => 'Darrèirs articles',
	'derniers_commentaires' => 'Darrèirs comentaris',
	'derniers_messages_forum' => 'Darrèirs messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En responsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau mesme autor',
	'meme_rubrique' => 'Dins la mesma rubrica',
	'memes_auteurs' => 'Daus mesmes autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots claus',
	'mots_clefs_meme_groupe' => 'Mots claus dins lo mesme grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats sobre lo web',
	'nouveaux_articles' => 'Articles nuòus',
	'nouvelles_breves' => 'Brèvas nuòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podètz participar a la vida d’aquel sit e prepausar los articles vòstres en vos inscriure çai sos. Recebretz tot sitòst un e-mail que vos indicará vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podètz prepausar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respondre a aquel article',
	'repondre_breve' => 'Respondre a aquela brèva',
	'resultats_recherche' => 'Resultats de la cèrcha',
	'retour_debut_forums' => 'Retorn au començament daus forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat amb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguda',
	'sur_web' => 'Sobre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Aquela letra recensa los articles e brèvas publicats dempuèi', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Vejatz en linha',
	'voir_squelette' => 'telecharjar l’esqueleta d’aquela pagina',
];
